==> ejc-zdsmaterialb-api-3.0.0-20241015.015712-31-sources.jar: com/ejianc/business/zdsmaterial/pick/vo/ProSubPickerVO.java <==
package com.ejianc.business.zdsmaterial.pick.vo;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包领料设置子表-领料人
 * 
 * @author generator
 * 
 */
public class ProSubPickerVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long settingId; // 领料设置id
    private Long settingSubcontractorId; // 领料分包商id
    private Long contractId; // 分包合同id
    private Long supplierId; // 分包供应商id
    private String supplierName; // 分包供应商
    private Long projectId; // 项目id
    private Long supplierEmpId; // 分包商领料人Id
    private String supplierEmpName; // 分包商领料人名称
    private String supplierEmpCode; // 分包商领料人编码
    private String supplierEmpPhone; // 分包商领料人电话
    private String pickerMemo; // 备注
    /**
     * 新加的
     */
    private Long supplierEmpFileId; // 授权委托书id
    private String supplierEmpCard; // 身份证件
    private Long supUserId; // 供方账号id
    private Long supTenantId; // 供方账号TenantId
    private String coordination; // 是否已生成供方租户：0-否，1-是
    private String enabledState; // 停用启用：0-停用，1-是

    public String getEnabledState() {
        return enabledState;
    }
    public String getCoordination() {
        return coordination;
    }

    public void setCoordination(String coordination) {
        this.coordination = coordination;
    }

    public Long getSupUserId() {
        return supUserId;
    }

    public void setSupUserId(Long supUserId) {
        this.supUserId = supUserId;
    }

    public Long getSupTenantId() {
        return supTenantId;
    }

    public void setSupTenantId(Long supTenantId) {
        this.supTenantId = supTenantId;
    }

    public Long getSupplierEmpFileId() {
        return supplierEmpFileId;
    }

    public void setSupplierEmpFileId(Long supplierEmpFileId) {
        this.supplierEmpFileId = supplierEmpFileId;
    }

    public String getSupplierEmpCard() {
        return supplierEmpCard;
    }

    public void setSupplierEmpCard(String supplierEmpCard) {
        this.supplierEmpCard = supplierEmpCard;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Long getSettingId() {
        return settingId;
    }

    public void setSettingId(Long settingId) {
        this.settingId = settingId;
    }
    public Long getSettingSubcontractorId() {
        return settingSubcontractorId;
    }

    public void setSettingSubcontractorId(Long settingSubcontractorId) {
        this.settingSubcontractorId = settingSubcontractorId;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getSupplierEmpId() {
        return supplierEmpId;
    }

    public void setSupplierEmpId(Long supplierEmpId) {
        this.supplierEmpId = supplierEmpId;
    }
    public String getSupplierEmpName() {
        return supplierEmpName;
    }

    public void setSupplierEmpName(String supplierEmpName) {
        this.supplierEmpName = supplierEmpName;
    }
    public String getSupplierEmpCode() {
        return supplierEmpCode;
    }

    public void setSupplierEmpCode(String supplierEmpCode) {
        this.supplierEmpCode = supplierEmpCode;
    }
    public String getSupplierEmpPhone() {
        return supplierEmpPhone;
    }

    public void setSupplierEmpPhone(String supplierEmpPhone) {
        this.supplierEmpPhone = supplierEmpPhone;
    }
    public String getPickerMemo() {
        return pickerMemo;
    }

    public void setPickerMemo(String pickerMemo) {
        this.pickerMemo = pickerMemo;
    }
    
}

==> ejc-zdsmaterialb-api-3.0.0-20251110.100127-75-sources.jar: com/ejianc/business/zdsmaterial/pick/vo/ProSubPickerVO.java <==
package com.ejianc.business.zdsmaterial.pick.vo;

import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 分包领料设置子表-领料人
 * 
 * @author generator
 * 
 */
public class ProSubPickerVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long settingId; // 领料设置id
    private Long settingSubcontractorId; // 领料分包商id
    private Long contractId; // 分包合同id
    private Long supplierId; // 分包供应商id
    private String supplierName; // 分包供应商
    private Long projectId; // 项目id
    private Long supplierEmpId; // 分包商领料人Id
    private String supplierEmpName; // 分包商领料人名称
    private String supplierEmpCode; // 分包商领料人编码
    private String supplierEmpPhone; // 分包商领料人电话
    private String pickerMemo; // 备注
    /**
     * 新加的
     */
    private Long supplierEmpFileId; // 授权委托书id
    private String supplierEmpCard; // 身份证件
    private Long supUserId; // 供方账号id
    private Long supTenantId; // 供方账号TenantId
    private String coordination; // 是否已生成供方租户：0-否，1-是
    private String enabledState; // 停用启用：0-停用，1-是

    public void setEnabledState(String enabledState) {
        this.enabledState = enabledState;
    }

    public String getEnabledState() {
        return enabledState;
    }
    public String getCoordination() {
        return coordination;
    }

    public void setCoordination(String coordination) {
        this.coordination = coordination;
    }

    public Long getSupUserId() {
        return supUserId;
    }

    public void setSupUserId(Long supUserId) {
        this.supUserId = supUserId;
    }

    public Long getSupTenantId() {
        return supTenantId;
    }

    public void setSupTenantId(Long supTenantId) {
        this.supTenantId = supTenantId;
    }

    public Long getSupplierEmpFileId() {
        return supplierEmpFileId;
    }

    public void setSupplierEmpFileId(Long supplierEmpFileId) {
        this.supplierEmpFileId = supplierEmpFileId;
    }

    public String getSupplierEmpCard() {
        return supplierEmpCard;
    }

    public void setSupplierEmpCard(String supplierEmpCard) {
        this.supplierEmpCard = supplierEmpCard;
    }

    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }

    public Long getSettingId() {
        return settingId;
    }

    public void setSettingId(Long settingId) {
        this.settingId = settingId;
    }
    public Long getSettingSubcontractorId() {
        return settingSubcontractorId;
    }

    public void setSettingSubcontractorId(Long settingSubcontractorId) {
        this.settingSubcontractorId = settingSubcontractorId;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public Long getSupplierEmpId() {
        return supplierEmpId;
    }

    public void setSupplierEmpId(Long supplierEmpId) {
        this.supplierEmpId = supplierEmpId;
    }
    public String getSupplierEmpName() {
        return supplierEmpName;
    }

    public void setSupplierEmpName(String supplierEmpName) {
        this.supplierEmpName = supplierEmpName;
    }
    public String getSupplierEmpCode() {
        return supplierEmpCode;
    }

    public void setSupplierEmpCode(String supplierEmpCode) {
        this.supplierEmpCode = supplierEmpCode;
    }
    public String getSupplierEmpPhone() {
        return supplierEmpPhone;
    }

    public void setSupplierEmpPhone(String supplierEmpPhone) {
        this.supplierEmpPhone = supplierEmpPhone;
    }
    public String getPickerMemo() {
        return pickerMemo;
    }

    public void setPickerMemo(String pickerMemo) {
        this.pickerMemo = pickerMemo;
    }
    
}
